@@ -113,7 +113,7 @@ void EnabledConnections::onWirelessHwEnabled(bool enabled)
 
 void EnabledConnections::onWimaxEnabled(bool enabled)
 {
-    m_wimaxEnabled = true;
+    m_wimaxEnabled = enabled;
     NMAppletDebug() << "Emit signal wimaxEnabled(" << enabled << ")";
     Q_EMIT wimaxEnabled(enabled);
 }
@@ -127,7 +127,7 @@ void EnabledConnections::onWimaxHwEnabled(bool enabled)
 
 void EnabledConnections::onWwanEnabled(bool enabled)
 {
-    m_wwanEnabled = true;
+    m_wwanEnabled = enabled;
     NMAppletDebug() << "Emit signal wwanEnabled(" << enabled << ")";
     Q_EMIT wwanEnabled(enabled);
 }
