@@ -32,6 +32,10 @@
 #include "bluetoothmonitor.h"
 
 #include <QDBusMetaType>
+#include <QDBusServiceWatcher>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusReply>
 
 K_PLUGIN_FACTORY(NetworkManagementServiceFactory, registerPlugin<NetworkManagementService>();)
 K_EXPORT_PLUGIN(NetworkManagementServiceFactory("networkmanagement", "plasmanetworkmanagement-kded"))
@@ -45,10 +49,34 @@ public:
 NetworkManagementService::NetworkManagementService(QObject * parent, const QVariantList&)
         : KDEDModule(parent), d_ptr(new NetworkManagementServicePrivate)
 {
-    Q_D(NetworkManagementService);
-
     KGlobal::insertCatalog("plasma_applet_org.kde.networkmanagement");  // mobile wizard
 
+    QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.plasma-desktop");
+    if (reply.value()) {
+        doInitialization();
+    } else {
+        QDBusServiceWatcher * watcher = new QDBusServiceWatcher("org.kde.plasma-desktop", QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+        connect(watcher, SIGNAL(serviceRegistered(QString)), SLOT(finishInitialization()));
+    }
+}
+
+NetworkManagementService::~NetworkManagementService()
+{
+    delete d_ptr;
+}
+
+void NetworkManagementService::finishInitialization()
+{
+    QDBusServiceWatcher * watcher = static_cast<QDBusServiceWatcher*>(sender());
+    disconnect(watcher, SIGNAL(serviceRegistered(QString)), this,  SLOT(finishInitialization()));
+
+    doInitialization();
+}
+
+void NetworkManagementService::doInitialization()
+{
+    Q_D(NetworkManagementService);
+
     d->agent = new SecretAgent(this);
     new Notification(this);
 #if WITH_MODEMMANAGER_SUPPORT
@@ -56,8 +84,3 @@ NetworkManagementService::NetworkManagementService(QObject * parent, const QVari
 #endif
     new BluetoothMonitor(this);
 }
-
-NetworkManagementService::~NetworkManagementService()
-{
-    delete d_ptr;
-}
