@@ -1,6 +1,6 @@
 /*
     Copyright 2013 Jan Grulich <jgrulich@redhat.com>
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    Copyright 2013, 2014 Lukas Tinkl <ltinkl@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -38,6 +38,9 @@
 #include <bridgewidget.h>
 #include <vlanwidget.h>
 #include <wimaxwidget.h>
+#if NM_CHECK_VERSION(0, 9, 9)
+#include <teamwidget.h>
+#endif
 #include "vpnuiplugin.h"
 
 #include <QDebug>
@@ -181,6 +184,8 @@ ConnectionDetailEditor::~ConnectionDetailEditor()
 
 void ConnectionDetailEditor::initEditor()
 {
+    enableOKButton(false);
+
     if (!m_new) {
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(m_connection->uuid());
         if (connection) {
@@ -309,6 +314,11 @@ void ConnectionDetailEditor::initTabs()
     } else if (type == NetworkManager::ConnectionSettings::Vlan) { // Vlan
         VlanWidget * vlanWidget = new VlanWidget(m_connection->setting(NetworkManager::Setting::Vlan), this);
         m_ui->tabWidget->addTab(vlanWidget, i18n("Vlan"));
+#if NM_CHECK_VERSION(0, 9, 9)
+    } else if (type == NetworkManager::ConnectionSettings::Team) { // Team
+        TeamWidget * teamWidget = new TeamWidget(uuid, m_connection->setting(NetworkManager::Setting::Team), this);
+        m_ui->tabWidget->addTab(teamWidget, i18n("Team"));
+#endif
     } else if (type == NetworkManager::ConnectionSettings::Wimax) { // Wimax
         WimaxWidget * wimaxWidget = new WimaxWidget(m_connection->setting(NetworkManager::Setting::Wimax), this);
         m_ui->tabWidget->addTab(wimaxWidget, i18n("Wimax"));
@@ -359,6 +369,9 @@ void ConnectionDetailEditor::initTabs()
          || type == ConnectionSettings::Wireless
          || type == ConnectionSettings::Infiniband
          || type == ConnectionSettings::Wimax
+     #if NM_CHECK_VERSION(0, 9, 9)
+         || type == ConnectionSettings::Team
+     #endif
          || type == ConnectionSettings::Bond
          || type == ConnectionSettings::Bridge
          || type == ConnectionSettings::Vlan) && !isSlave()) {
